Crate hnefatafl_copenhagen

Crate hnefatafl_copenhagen 

An AI, client, engine, and server for the game of Copenhagen Hnefatafl.

Feature Flags

By default the client and server feature flags are enabled.

  • client - enable the hnefatafl-client binary
  • console - on Windows print output to the console
  • debug - enable iced debug mode, also log on the debug level
  • js - enable options for generating javascript code
  • runic - enable the icelandic-runic binary for translating Icelandic to Icelandic Runic
  • server - enable the hnefatafl-server-full binary

Message Protocol

Get more information about the message protocol used by the engine.

Modules

accounts
ai
board
characters
draw
email
game
glicko
heat_map
locale
play
rating
role
server_game
space
status
time
tournament
tree
utils

Constants

COPYRIGHT
HOME
LONG_VERSION
SERVER_PORT
SOCKET_PATH
VERSION_ID

Functions

read_response
Errors
tcp_keep_alive
write_command
Errors

Type Aliases

Id