An AI, client, engine, and server for the game of Copenhagen Hnefatafl.
Feature Flags
By default the client and server feature flags are enabled.
- client - enable the
hnefatafl-clientbinary - console - on Windows print output to the console
- debug - enable iced debug mode, also log on the debug level
- js - enable options for generating javascript code
- runic - enable the
icelandic-runicbinary for translating Icelandic to Icelandic Runic - server - enable the
hnefatafl-server-fullbinary
Message Protocol
Get more information about the message protocol used by the engine.
Modules
- accounts
- ai
- board
- characters
- draw
- game
- glicko
- heat_
map - locale
- play
- rating
- role
- server_
game - space
- status
- time
- tournament
- tree
- utils
Constants
Functions
- read_
response - Errors
- tcp_
keep_ alive - write_
command - Errors